globalVariables(unique(c(
  "runif", "rpois", "rbinom", "x", "y", "aes", "error", "value",
  "sample_size_mat_list", "bind_cols", "random_mpm"
)))
